@@ -6,7 +6,7 @@ use Illuminate\Contracts\View\View;
 use Illuminate\Support\Collection;
 
 use App\Classes\LDAP\Attribute;
-use App\Ldap\Entry;
+use App\Classes\Template;
 
 /**
  * Represents an attribute whose value is a Kerberos Ticket Flag
@@ -50,14 +50,19 @@ final class KrbTicketFlags extends Attribute
 		return $helpers;
 	}
 
-	public function render(bool $edit=FALSE,bool $old=FALSE,bool $new=FALSE,string $langtag=Entry::TAG_NOTAG,bool $updated=FALSE): View
+	public function render(string $attrtag,int $index,bool $edit=FALSE,bool $editable=FALSE,bool $new=FALSE,bool $updated=FALSE,?Template $template=NULL): View
 	{
-		return view('components.attribute.krbticketflags')
+		return view('components.attribute.value.krbticketflags')
 			->with('o',$this)
+			->with('dotkey',$dotkey=$this->dotkey($attrtag,$index))
+			->with('value',$this->render_item_new($dotkey))
 			->with('edit',$edit)
-			->with('old',$old)
+			->with('editable',$editable)
 			->with('new',$new)
+			->with('attrtag',$attrtag)
+			->with('index',$index)
 			->with('updated',$updated)
+			->with('template',$template)
 			->with('helper',static::helpers());
 	}
 }
\ No newline at end of file
