@@ -7,6 +7,7 @@ use Illuminate\Support\Arr;
 use Illuminate\Support\Facades\Cache;
 
 use App\Classes\LDAP\Attribute;
+use App\Classes\Template;
 
 /**
  * Represents an attribute whose values are schema related
@@ -14,6 +15,7 @@ use App\Classes\LDAP\Attribute;
 abstract class Schema extends Attribute
 {
 	protected bool $internal = TRUE;
+	protected(set) bool $no_attr_tags = TRUE;
 
 	protected static function _get(string $filename,string $string,string $key): ?string
 	{
@@ -30,7 +32,7 @@ abstract class Schema extends Attribute
 			while (! feof($f)) {
 				$line = trim(fgets($f));
 
-				if (! $line OR preg_match('/^#/',$line))
+				if ((! $line) || preg_match('/^#/',$line))
 					continue;
 
 				$fields = explode(':',$line);
@@ -41,18 +43,23 @@ abstract class Schema extends Attribute
 					'desc'=>Arr::get($fields,3,__('No description available, can you help with one?')),
 				]);
 			}
+
 			fclose($f);
 
 			return $result;
 		});
 
-		return Arr::get(($array ? $array->get($string) : []),$key);
+		return Arr::get(($array ? $array->get($string) : []),
+			$key,
+			$key === 'title' ? $string : __('No description available, can you help with one?'));
 	}
 
-	public function render(bool $edit=FALSE,bool $old=FALSE,bool $new=FALSE): View
+	public function render(string $attrtag,int $index,bool $edit=FALSE,bool $editable=FALSE,bool $new=FALSE,bool $updated=FALSE,?Template $template=NULL): View
 	{
 		// @note Schema attributes cannot be edited
-		return view('components.attribute.internal')
-			->with('o',$this);
+		return view('components.attribute.schema.generic')
+			->with('o',$this)
+			->with('dotkey',$dotkey=$this->dotkey($attrtag,$index))
+			->with('value',$this->render_item_new($dotkey));
 	}
 }
\ No newline at end of file
