@@ -3,10 +3,16 @@
 namespace App\Ldap;
 
 use Illuminate\Support\Collection;
+use Illuminate\Support\Facades\Cache;
 use Illuminate\Support\Facades\Crypt;
+use Illuminate\Support\Facades\Log;
+use Illuminate\Support\Facades\Session;
+use Illuminate\Support\Facades\Storage;
+use Illuminate\Support\Str;
 use LdapRecord\Support\Arr;
 use LdapRecord\Models\Model;
 
+use App\Classes\Template;
 use App\Classes\LDAP\Attribute;
 use App\Classes\LDAP\Attribute\Factory;
 use App\Classes\LDAP\Export\LDIF;
@@ -20,22 +26,34 @@ use App\Exceptions\InvalidUsage;
  */
 class Entry extends Model
 {
+	private const LOGKEY = 'E--';
+
 	private const TAG_CHARS = 'a-zA-Z0-9-';
-	private const TAG_CHARS_LANG = 'lang-['.self::TAG_CHARS.']';
+	public const LANG_TAG_PREFIX = 'lang-';
+	public const TAG_CHARS_LANG = self::LANG_TAG_PREFIX.'['.self::TAG_CHARS.']+';
 	public const TAG_NOTAG = '_null_';
+	public const TAG_MD5 = '_md5_';
+	public const TAG_HELPER = '_helper_';
+	public const TAG_NOVALUES = [self::TAG_MD5,self::TAG_HELPER];
 
 	// Our Attribute objects
 	private Collection $objects;
+
+	// Templates that apply to this entry
+	private(set) Collection $templates;
+
 	// For new entries, this is the container that this entry will be stored in
-	private string $rdnbase;
+	private string $rdnbase = '';
+	private(set) bool $is_base;
 
 	/* OVERRIDES */
 
 	public function __construct(array $attributes = [])
 	{
-		$this->objects = collect();
-
 		parent::__construct($attributes);
+
+		$this->objects = collect();
+		$this->templates = collect();
 	}
 
 	public function discardChanges(): static
@@ -58,14 +76,37 @@ class Entry extends Model
 	public function getAttributes(): array
 	{
 		return $this->objects
+			->filter(fn($item)=>(! $item->is_internal))
 			->flatMap(fn($item)=>
-				($item->no_attr_tags)
-					? [strtolower($item->name)=>$item->values]
-					: $item->values
-						->flatMap(fn($v,$k)=>[strtolower($item->name.($k !== self::TAG_NOTAG ? ';'.$k : ''))=>$v]))
+				$item->values
+					->flatMap(fn($v,$k)=>[strtolower($item->name.(($k !== self::TAG_NOTAG) ? ';'.$k : ''))=>$v]))
 			->toArray();
 	}
 
+	/**
+	 * This replaces the model's get dirty, given that we store LDAP attributes in $this->objects, replacing
+	 * $this->original/$this->attributes
+	 *
+	 * @return array
+	 */
+	public function getDirty(): array
+	{
+		$result = collect();
+
+		foreach ($this->objects as $o)
+			if ($o->isDirty())
+				$result = $result->merge($o->getDirty());
+
+		$result = $result
+			->flatMap(function($item,$attr) {
+				return ($x=collect($item))->count()
+					? $x->flatMap(fn($v,$k)=>[strtolower($attr.(($k !== self::TAG_NOTAG) ? ';'.$k : ''))=>$v])
+					: [strtolower($attr)=>[]];
+			});
+
+		return $result->toArray();
+	}
+
 	/**
 	 * Determine if the new and old values for a given key are equivalent.
 	 */
@@ -83,6 +124,9 @@ class Entry extends Model
 	 * As attribute values are updated, or new ones created, we need to mirror that
 	 * into our $objects. This is called when we $o->key = $value
 	 *
+	 * If $value is an array, it should be an array of [tag => values]
+	 * If $value is a string, then the key may have the tag "attribute;tag = value", and the tag is taken from the key
+	 *
 	 * This function should update $this->attributes and correctly reflect changes in $this->objects
 	 *
 	 * @param string $key
@@ -91,14 +135,26 @@ class Entry extends Model
 	 */
 	public function setAttribute(string $key,mixed $value): static
 	{
+		if (! is_array($value))
+			throw new \Exception('Value must be an array');
+
 		foreach ($value as $k => $v)
 			parent::setAttribute($key.($k !== self::TAG_NOTAG ? ';'.$k : ''),$v);
 
 		$key = $this->normalizeAttributeKey($key);
-		list($attribute,$tags) = $this->keytag($key);
+		list($attribute,$tag) = $this->keytag($key);
 
-		$o = $this->objects->get($attribute) ?: Factory::create($this->dn ?: '',$attribute,[],Arr::get($this->attributes,'objectclass',[]));
-		$o->values = collect($value);
+		$o = $this->objects->get($attribute)
+			?: Factory::create(
+				dn: $this->dn ?: '',
+				attribute: $attribute,
+				values: [$tag=>Arr::get($this->original,$tag,[])],
+				oc: Arr::get($this->attributes,'objectclass',[]));
+
+		if (is_array($value))
+			$o->setValues($value);
+		else
+			$o->addValue($tag,$value);
 
 		$this->objects->put($key,$o);
 
@@ -118,18 +174,45 @@ class Entry extends Model
 		parent::setRawAttributes($attributes);
 
 		// We only set our objects on DN entries (otherwise we might get into a recursion loop if this is the schema DN)
-		if ($this->dn && (! in_array($this->dn,Arr::get($this->attributes,'subschemasubentry',[])))) {
+		if ($this->dn && ($this->dn !== config('server')->schemaDN())) {
 			$this->objects = $this->getAttributesAsObjects();
 
 		} else {
 			$this->objects = collect();
 		}
 
+		// Filter out our templates specific for this entry
+		if ($this->dn && ($this->dn !== config('server')->schemaDN())) {
+			$this->templates = $this->templates()
+				->filter(fn($item)=>$item->enabled
+					&& (! $item->objectclasses
+						->map('strtolower')
+						->diff(array_map('strtolower',Arr::get($this->attributes,'objectclass')))
+						->count()))
+				->sortBy(fn($item)=>$item->title);
+		}
+
 		return $this;
 	}
 
 	/* ATTRIBUTES */
 
+	/**
+	 * Return an RDN object
+	 *
+	 * @return Attribute\RDN
+	 * @throws InvalidUsage
+	 */
+	public function getRDNAttribute(): Attribute\RDN
+	{
+		$rdn = explode('=',$this->getRdn());
+		$o = new Attribute\RDN('','dn',[self::TAG_NOTAG=>(array_filter($rdn) && (count($rdn) === 2)) ? [$rdn[0]=>$rdn[1]] : [NULL]]);
+		$o->setBase($this->getContainer());
+		$o->setAttributes($this->getAvailableAttributes()->filter(fn($item)=>$item->is_must));
+
+		return $o;
+	}
+
 	/**
 	 * Return a key to use for sorting
 	 *
@@ -153,21 +236,23 @@ class Entry extends Model
 	 * @throws AttributeException
 	 * @note Attributes added this way dont have objectclass information, and the Model::attributes are not populated
 	 */
-	public function addAttributeItem(string $key,mixed $value): void
+	public function addAttributeItem(string $key,string $value): void
 	{
-		// While $value is mixed, it can only be a string
-		if (! is_string($value))
-			throw new \Exception('value should be a string');
-
 		$key = $this->normalizeAttributeKey(strtolower($key));
 
 		// If the attribute name has tags
 		list($attribute,$tag) = $this->keytag($key);
 
-		if (! config('server')->schema('attributetypes')->has($attribute))
+		if (config('server')->get_attr_id($attribute) === FALSE)
 			throw new AttributeException(sprintf('Schema doesnt have attribute [%s]',$attribute));
 
-		$o = $this->objects->get($attribute) ?: Attribute\Factory::create($this->dn ?: '',$attribute,[]);
+		$o = $this->objects->get($attribute)
+			?: Factory::create(
+				dn: $this->dn ?: '',
+				attribute: $attribute,
+				values: [$tag=>Arr::get($this->original,$tag,[])],
+			);
+
 		$o->addValue($tag,[$value]);
 
 		$this->objects->put($attribute,$o);
@@ -213,24 +298,43 @@ class Entry extends Model
 		$result = collect();
 		$entry_oc = Arr::get($this->attributes,'objectclass',[]);
 
-		foreach ($this->attributes as $attrtag => $values) {
-			list($attribute,$tags) = $this->keytag($attrtag);
-
-			$orig = Arr::get($this->original,$attrtag,[]);
+		// Set the initial attributes
+		foreach ($this->original as $attrtag => $values) {
+			list($attribute,$tag) = $this->keytag($attrtag);
 
 			// If the attribute doesnt exist we'll create it
 			$o = Arr::get(
 				$result,
 				$attribute,
 				Factory::create(
-					$this->dn,
-					$attribute,
-					[$tags=>$orig],
-					$entry_oc,
+					dn: $this->dn,
+					attribute: $attribute,
+					values: [$tag=>$values],
+					oc: $entry_oc,
 				));
 
-			$o->addValue($tags,$values);
-			$o->addValueOld($tags,Arr::get($this->original,$attrtag));
+			$o->addValueOld($tag,$values);
+			$o->addValue($tag,$values);
+
+			$result->put($attribute,$o);
+		}
+
+		// Get any changes
+		foreach ($this->attributes as $attrtag => $values) {
+			list($attribute,$tag) = $this->keytag($attrtag);
+
+			// If the attribute doesnt exist we'll create it
+			$o = Arr::get(
+				$result,
+				$attribute,
+				Factory::create(
+					dn: $this->dn,
+					attribute: $attribute,
+					values: [$tag=>Arr::get($this->original,$attrtag,[])],
+					oc: $entry_oc,
+				));
+
+			$o->addValue($tag,$values);
 
 			$result->put($attribute,$o);
 		}
@@ -273,12 +377,17 @@ class Entry extends Model
 	{
 		$result = collect();
 
-		foreach (($this->getObject('objectclass')?->values ?: []) as $oc)
-			$result = $result->merge(config('server')->schema('objectclasses',$oc)->attributes);
+		foreach (($this->getObject('objectclass')?->values->dot() ?: []) as $oc)
+			$result = $result->merge(config('server')->schema('objectclasses',$oc)->all_attributes);
 
 		return $result;
 	}
 
+	public function getContainer(): string
+	{
+		return $this->rdnbase ?: dn_container($this->getDn());
+	}
+
 	/**
 	 * Return a secure version of the DN
 	 * @param string $cmd
@@ -289,6 +398,11 @@ class Entry extends Model
 		return Crypt::encryptString(($cmd ? sprintf('*%s|',$cmd) : '').$this->getDn());
 	}
 
+	public function getDNContainerSecure(string $cmd=''): string
+	{
+		return Crypt::encryptString(($cmd ? sprintf('*%s|',$cmd) : '').$this->getContainer());
+	}
+
 	/**
 	 * Return a list of LDAP internal attributes
 	 *
@@ -308,14 +422,7 @@ class Entry extends Model
 	public function getLangTags(): Collection
 	{
 		return $this->getObjects()
-			->filter(fn($item)=>! $item->no_attr_tags)
-			->map(fn($item)=>$item
-				->values
-				->keys()
-				->filter(fn($item)=>preg_match(sprintf('/%s+;?/',self::TAG_CHARS_LANG),$item))
-				->map(fn($item)=>preg_replace('/lang-/','',$item))
-			)
-			->filter(fn($item)=>$item->count());
+			->map(fn($item)=>$item->langtags);
 	}
 
 	/**
@@ -336,16 +443,12 @@ class Entry extends Model
 	 * Get an attribute as an object
 	 *
 	 * @param string $key
-	 * @return Attribute|null
+	 * @return Attribute|NULL
 	 */
-	public function getObject(string $key): Attribute|null
+	public function getObject(string $key): Attribute|NULL
 	{
-		return match ($key) {
-			'rdn' => $this->getRDNObject(),
-
-			default => $this->objects
-				->get($this->normalizeAttributeKey($key))
-		};
+		return $this->objects
+			->get($this->normalizeAttributeKey($key));
 	}
 
 	public function getObjects(): Collection
@@ -373,7 +476,7 @@ class Entry extends Model
 					$item && collect(explode(';',$item))->filter(
 						fn($item)=>
 							(! preg_match(sprintf('/^%s$/',self::TAG_NOTAG),$item))
-							&& (! preg_match(sprintf('/^%s+$/',self::TAG_CHARS_LANG),$item))
+							&& (! preg_match(sprintf('/^%s$/',self::TAG_CHARS_LANG),$item))
 						)
 						->count())
 			)
@@ -384,9 +487,6 @@ class Entry extends Model
 	 * Return a list of attributes without any values
 	 *
 	 * @return Collection
-	 * @todo Dont show attributes that are not provided by an objectclass, make a new function to show those
-	 *       This is for dynamic list items eg: labeledURI, which are not editable.
-	 *       We can highlight those values that are as a result of a dynamic module
 	 */
 	public function getMissingAttributes(): Collection
 	{
@@ -394,35 +494,20 @@ class Entry extends Model
 			->filter(fn($a)=>(! $this->getVisibleAttributes()->contains(fn($b)=>($a->name === $b->name))));
 	}
 
-	private function getRDNObject(): Attribute\RDN
-	{
-		$o = new Attribute\RDN('','dn',['']);
-		// @todo for an existing object, rdnbase would be null, so dynamically get it from the DN.
-		$o->setBase($this->rdnbase);
-		$o->setAttributes($this->getAvailableAttributes()->filter(fn($item)=>$item->required));
-
-		return $o;
-	}
-
 	/**
 	 * Return this list of user attributes
 	 *
-	 * @param string $tag If null return all tags
 	 * @return Collection
 	 */
-	public function getVisibleAttributes(string $tag=''): Collection
+	public function getVisibleAttributes(): Collection
 	{
-		static $cache = [];
+		static $cache = collect();
 
-		if (! Arr::get($cache,$tag ?: '_all_')) {
-			$ot = $this->getOtherTags();
+		if (! $cache->count())
+			$cache = $this->objects
+				->filter(fn($item)=>(! $item->is_internal));
 
-			$cache[$tag ?: '_all_'] = $this->objects
-				->filter(fn($item)=>(! $item->is_internal) && ((! $item->no_attr_tags) || (! $tag) || ($tag === Entry::TAG_NOTAG)))
-				->filter(fn($item)=>(! $tag) || $ot->has($item->name_lc) || count($item->tagValues($tag)) > 0);
-		}
-
-		return $cache[$tag ?: '_all_'];
+		return $cache;
 	}
 
 	public function hasAttribute(int|string $key): bool
@@ -431,6 +516,21 @@ class Entry extends Model
 			->has($key);
 	}
 
+	/**
+	 * Did this query generate a size limit exception
+	 *
+	 * @return bool
+	 * @throws \LdapRecord\ContainerException
+	 */
+	public function hasMore(): bool
+	{
+		return $this->getConnectionContainer()
+			->getConnection()
+			->getLdapConnection()
+			->getDetailedError()
+			?->getErrorCode() === 4;
+	}
+
 	/**
 	 * Return an icon for a DN based on objectClass
 	 *
@@ -525,11 +625,45 @@ class Entry extends Model
 		return [$attribute,$tags];
 	}
 
+	/**
+	 * Is this entry a baseDN
+	 *
+	 * @return void
+	 */
+	public function setBase(): void
+	{
+		$this->is_base = TRUE;
+	}
+
 	public function setRDNBase(string $bdn): void
 	{
 		if ($this->exists)
 			throw new InvalidUsage('Cannot set RDN base on existing entries');
 
 		$this->rdnbase = $bdn;
+
+		// Load any templates
+		$this->templates = $this->templates()
+			->filter(fn($item)=>(! $item->regexp) || preg_match($item->regexp,$bdn));
+	}
+
+	private function templates(): Collection
+	{
+		return Cache::remember('templates'.Session::id(),config('ldap.cache.time'),function() {
+			$template_dir = Storage::disk(config('pla.template.dir'));
+			$templates = collect();
+
+			foreach (array_filter($template_dir->files('.',TRUE),fn($item)=>Str::endsWith($item,'.json')) as $file) {
+				if (config('pla.template.exclude_system',FALSE) && Str::doesntContain($file,'/'))
+					continue;
+
+				$to = new Template($file);
+
+				if (! $to->invalid)
+					$templates->put($file,$to);
+			}
+
+			return $templates;
+		});
 	}
 }
\ No newline at end of file
