@@ -4,7 +4,7 @@ use Illuminate\Foundation\Application;
 use Illuminate\Foundation\Configuration\Exceptions;
 use Illuminate\Foundation\Configuration\Middleware;
 
-use App\Http\Middleware\{AllowAnonymous,ApplicationSession,CheckUpdate,SwapinAuthUser,ViewVariables};
+use App\Http\Middleware\{AcceptLanguage,AllowAnonymous,CheckUpdate,SwapinAuthUser,ViewVariables};
 
 return Application::configure(basePath: dirname(__DIR__))
 	->withRouting(
@@ -16,7 +16,7 @@ return Application::configure(basePath: dirname(__DIR__))
 		$middleware->appendToGroup(
 			group: 'web',
 			middleware: [
-				ApplicationSession::class,
+				AcceptLanguage::class,
 				AllowAnonymous::class,
 				SwapinAuthUser::class,
 				ViewVariables::class,
@@ -27,7 +27,7 @@ return Application::configure(basePath: dirname(__DIR__))
 			'10.0.0.0/8',
 			'127.0.0.0/8',
 			'172.16.0.0/12',
-			'192.168.0.0/12',
+			'192.168.0.0/16',
 		]);
 	})
 	->withExceptions(function (Exceptions $exceptions) {
