@@ -1,9 +1,10 @@
+@use(App\Classes\LDAP\Attribute\Schema\OID)
 @extends('layouts.dn')
 
 @section('page_title')
 	<table class="table table-borderless">
 		<tr>
-			<td style="border-radius: 5px;"><div class="page-title-icon f32"><i class="fas fa-info"></i></div></td>
+			<td><div class="page-title-icon f32"><i class="fas fa-info"></i></div></td>
 			<td class="top text-end align-text-top p-2"><strong>@lang('Server Info')</strong><br><small>{{ $server->rootDSE()->entryuuid[0] ?? '' }}</small></td>
 		</tr>
 	</table>
@@ -13,7 +14,7 @@
 	<div class="main-card mb-3 card">
 		<div class="card-body">
 			<table class="table">
-				@foreach ($server->rootDSE()->getObjects() as $attribute => $ao)
+				@foreach($server->rootDSE()->getObjects() as $attribute => $ao)
 					<tr>
 						<th class="w-25">
 							{!! ($x=$server->schema('attributetypes',$attribute))
@@ -21,7 +22,14 @@
 								: $attribute !!}
 						</th>
 						<td>
-							<x-attribute :edit="false" :o="$ao"/>
+							@switch(get_class($ao))
+								@case(OID::class)
+									<x-attribute.values :o="$ao" :new="false"/>
+									@break
+
+								@default
+									{!! collect(explode("\n",(string)$ao))->join('<br>') !!}
+							@endswitch
 						</td>
 					</tr>
 				@endforeach
